@@ -1,33 +1,15 @@
 # repoze TransactionManager WSGI middleware
 import sys
+
 import transaction
 
 ekey = 'repoze.tm.active'
 
-PY3 = sys.version_info[0] >= 3
 
-if PY3: #pragma NO COVER Py3k
-    def reraise(tp, value, tb=None):
-        if value.__traceback__ is not tb:
-            raise value.with_traceback(tb)
-        raise value
-else:   #pragma NO COVER Python2
-    def exec_(_code_, _globs_=None, _locs_=None):
-        """Execute code in a namespace."""
-        if _globs_ is None:
-            frame = sys._getframe(1)
-            _globs_ = frame.f_globals
-            if _locs_ is None:
-                _locs_ = frame.f_locals
-            del frame
-        elif _locs_ is None: #pragma NO COVER
-            _locs_ = _globs_
-        exec("""exec _code_ in _globs_, _locs_""")
-
-    exec_("""def reraise(tp, value, tb=None):
-    raise tp, value, tb
-""")
-    del exec_
+def reraise(tp, value, tb=None):
+    if value.__traceback__ is not tb:  # pragma: NO COVER
+        raise value.with_traceback(tb)
+    raise value
 
 
 class TM:
@@ -174,6 +156,6 @@ def make_tm(app, global_conf, commit_veto=None):
     """ Paste filter_app_factory entry point for creation of a TM middleware."""
     from pkg_resources import EntryPoint
     if commit_veto is not None:
-        commit_veto = EntryPoint.parse('x=%s' % commit_veto).load(False)
+        commit_veto = EntryPoint.parse('x=%s' % commit_veto).resolve()
     return TM(app, commit_veto)
 
